@@ -333,7 +333,7 @@ stan_sar <- function(formula,
         y_int = y_int,
         trials = rep(0, length(y)),
         n = n,
-        offset = offset,
+        input_offset = offset,
         has_re = has_re,
         n_ids = n_ids,
         id = id_index$idx,
